@@ -9,8 +9,9 @@ from google.cloud import storage
 
 
 class Cloudstore:
-    def __init__(self):
-        self.bucket_name = os.getenv("BUCKET_NAME", "ph-gandai-dev")
+    def __init__(self, stage="staging"):
+        BUCKET_NAME = f"ph-gandai-{stage}"
+        self.bucket_name = BUCKET_NAME
         self.client = storage.Client(project=os.getenv("PROJECT_NAME", "gandai-dev"))
         self.bucket = self.client.get_bucket(self.bucket_name)
 
